@@ -2,10 +2,11 @@
 Internal module for making requests to external APIs. It wraps the requests
 module to provide friendlier error messages and defaults
 """
-import requests
 import json
 from json import JSONDecodeError
 
+import requests
+
 from ploomber.exceptions import NetworkException, RawBaseException
 
 
@@ -41,15 +42,18 @@ def _request(method, url, params=None, json_error=False, **kwargs):
 
         if json_ is None:
             raise NetworkException(
-                f"An error happened (code: {response.status_code})")
+                f"An error happened (code: {response.status_code})",
+                code=response.status_code)
 
         message = json_.get("Message")
 
         if message and not json_error:
             raise NetworkException(
-                f'{message} (status: {response.status_code})')
+                f'{message} (status: {response.status_code})',
+                code=response.status_code)
         elif not message and not json_error:
-            raise NetworkException(f'Error: {json_}')
+            raise NetworkException(f'Error: {json_}',
+                                   code=response.status_code)
         else:
             raise RawBaseException(json.dumps(json_))
 
